@@ -359,6 +359,8 @@ void KateViewSpace::insertTab(int index, KTextEditor::Document * doc)
 
     connect(doc, SIGNAL(documentNameChanged(KTextEditor::Document*)),
             this, SLOT(updateDocumentName(KTextEditor::Document*)));
+    connect(doc, &KTextEditor::Document::documentUrlChanged,
+            this, &KateViewSpace::updateDocumentUrl);
     connect(doc, SIGNAL(modifiedChanged(KTextEditor::Document*)),
             this, SLOT(updateDocumentState(KTextEditor::Document*)));
 }
@@ -380,6 +382,8 @@ int KateViewSpace::removeTab(KTextEditor::Document * doc, bool documentDestroyed
     if (!documentDestroyed) {
         disconnect(doc, SIGNAL(documentNameChanged(KTextEditor::Document*)),
                this, SLOT(updateDocumentName(KTextEditor::Document*)));
+        disconnect(doc, &KTextEditor::Document::documentUrlChanged,
+                this, &KateViewSpace::updateDocumentUrl);
         disconnect(doc, SIGNAL(modifiedChanged(KTextEditor::Document*)),
               this, SLOT(updateDocumentState(KTextEditor::Document*)));
     }
@@ -498,6 +502,13 @@ void KateViewSpace::updateDocumentName(KTextEditor::Document *doc)
     m_tabBar->setTabToolTip(buttonId, doc->url().toDisplayString());
 }
 
+void KateViewSpace::updateDocumentUrl(KTextEditor::Document *doc)
+{
+    const int buttonId = m_docToTabId[doc];
+    Q_ASSERT(buttonId >= 0);
+    m_tabBar->setTabUrl(buttonId, doc->url());
+}
+
 void KateViewSpace::updateDocumentState(KTextEditor::Document *doc)
 {
     QIcon icon;
@@ -579,11 +590,11 @@ void KateViewSpace::showContextMenu(int id, const QPoint & globalPos)
     Q_ASSERT(doc);
 
     QMenu menu(this);
-    QAction *aCloseTab = menu.addAction(i18n("&Close Document"));
-    QAction *aCloseOthers = menu.addAction(i18n("Close Other &Documents"));
+    QAction *aCloseTab = menu.addAction(QIcon::fromTheme(QStringLiteral("tab-close")), i18n("&Close Document"));
+    QAction *aCloseOthers = menu.addAction(QIcon::fromTheme(QStringLiteral("tab-close-other")), i18n("Close Other &Documents"));
     menu.addSeparator();
-    QAction *aCopyPath = menu.addAction(i18n("Copy &Path"));
-    QAction *aOpenFolder = menu.addAction(i18n("&Open Containing Folder"));
+    QAction *aCopyPath = menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy &Path"));
+    QAction *aOpenFolder = menu.addAction(QIcon::fromTheme(QStringLiteral("document-open-folder")), i18n("&Open Containing Folder"));
 
     if (KateApp::self()->documentManager()->documentList().count() < 2) {
         aCloseOthers->setEnabled(false);
